@@ -32,17 +32,18 @@ public:
         parent(p)
     {
         Q_ASSERT(0 != dbusAdaptor);
-        databaseUtility->openDatabase();
+        //Do not open here - Unable to capture changes to DB if it is open too early and closed late.
+        //databaseUtility->openDatabase();
     }
 
     ~CallRouterPrivate()
     {
         qDebug() << "VICaR: Call Router Destructing";
-        databaseUtility->closeDatabase();
+        //databaseUtility->closeDatabase();
     }
 
-    VicarDbusAdaptor * dbusAdaptor;
     DatabaseUtility *databaseUtility;
+    VicarDbusAdaptor * dbusAdaptor;
     DbusUtility * dbusUtility;
     GConfUtility * gconfUtility;
     TelepathyUtility *tpUtility;
@@ -66,7 +67,8 @@ CallRouter::~CallRouter(){
 }
 
 void CallRouter::registerDBusService(){
-    QDBusConnection connection = d->dbusUtility->getConnection();
+    //Connect to Session Bus
+    QDBusConnection connection = d->dbusUtility->getConnection(false);
 
     if (!connection.interface()->isServiceRegistered(APPLICATION_DBUS_SERVICE)){
 
@@ -86,7 +88,8 @@ void CallRouter::registerDBusService(){
 
 void CallRouter::unregisterDBusService(){
 
-    QDBusConnection connection = d->dbusUtility->getConnection();
+    //Disconnect from Session bus
+    QDBusConnection connection = d->dbusUtility->getConnection(false);
 
     connection.unregisterObject(APPLICATION_DBUS_PATH,QDBusConnection::UnregisterTree);
 
@@ -101,49 +104,51 @@ QString CallRouter::callViaCallingCard(QString strDestinationNumber){
 
         d->currentProfile = new org::maemo::vicar::Profile();
         d->currentProfile->profileID = 0;
+
+        d->databaseUtility->openDatabase();
         bool result = d->databaseUtility->findProfileByNumber(strDestinationNumber,d->currentProfile);
+
         QString strErrorMessage;
         if (!result){
             strErrorMessage = QString("Error finding VICaR profile. %1").arg(d->databaseUtility->lastError().text());
-            return strErrorMessage;
         }
         else if (d->currentProfile->profileID == 0){
             bool routeOnDefault = d->gconfUtility->getGconfValueBoolean("route_on_default");
             if (routeOnDefault){
                 qDebug() << "Routing directly as per configuration";
                this->placeCall(strDestinationNumber);
-               return strErrorMessage;
             }
             else{
                 qDebug() << "No profile found. Stopping..";
                 strErrorMessage  = "VICaR: No routing profile defined for this number.";
                 d->dbusUtility->displayNotification(strErrorMessage );
-                return strErrorMessage;
             }
         }
+        else{
+            //Now call the calling card number. This is generally a local and/or tollfree number
+            QString strCallingCardNumber = d->currentProfile->gatewayNumber;
+            qDebug() << "Initiating call to "<< strCallingCardNumber;
+            bool status = this->placeCall(strCallingCardNumber);
+            d->strLastDialedNumber = strDestinationNumber;
 
-        //Now call the calling card number. This is generally a local and/or tollfree number
-        QString strCallingCardNumber = d->currentProfile->gatewayNumber;
-        qDebug() << "Initiating call to "<< strCallingCardNumber;
-        bool status = this->placeCall(strCallingCardNumber);
-        d->strLastDialedNumber = strDestinationNumber;
+            QString strUserMessage;
 
-        QString strUserMessage;
-
-        if (status){
-            qDebug() << "Call initiated successfully. Connecting DBus slot for audio connection monitor";
-             startCallStatusMonitors();
-        }
-        else {
-            strUserMessage = QString("Unable to initiate new call to ").append(strCallingCardNumber);
-            strErrorMessage = d->dbusUtility->getErrorMessage();
-            qDebug() << strErrorMessage;
-            d->strLastDialedNumber.clear();
-            delete d->currentProfile;
-            d->currentProfile = 0;
+            if (status){
+                qDebug() << "Call initiated successfully. Connecting DBus slot for audio connection monitor";
+                 startCallStatusMonitors();
+            }
+            else {
+                strUserMessage = QString("Unable to initiate new call to ").append(strCallingCardNumber);
+                strErrorMessage = d->dbusUtility->getErrorMessage();
+                qDebug() << strErrorMessage;
+                d->strLastDialedNumber.clear();
+                delete d->currentProfile;
+                d->currentProfile = 0;
+            }
+            d->dbusUtility->displayNotification(strUserMessage);
         }
 
-        d->dbusUtility->displayNotification(strUserMessage);
+        d->databaseUtility->closeDatabase();
         return strErrorMessage;
 }
 
