@@ -453,7 +453,7 @@ QDBusObjectPath Connection::processChannel(const QVariantMap &request){
 
     //Initiate a new call to CC/Google Out/Skype-out number by requesting a new channel with Ring CM.
 
-    VicarCallRouterProxy *callRouter = new VicarCallRouterProxy(APPLICATION_DBUS_SERVICE,APPLICATION_DBUS_PATH,QDBusConnection::systemBus(),this);
+    VicarCallRouterProxy *callRouter = new VicarCallRouterProxy(APPLICATION_DBUS_SERVICE,APPLICATION_DBUS_PATH,QDBusConnection::sessionBus(),this);
 
     callRouter->callInternationalNumber(strNumber);
 
